TelnetCommand class abstract

Constructors

TelnetCommand()

Properties

command String
no setter
description String
no setter
hashCode int
The hash code for this object.
no setterinherited
label String
no setter
parameters List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildCommand(List<String> args) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited